@@ -10,11 +10,16 @@ class FieldSchema:
     schema for the extraction of a single datafield
     use together with RecordSchema
     """
+
     name: str
     dtype: Type
     default: Any = None
     transform: Callable | None = None
-    rename: str | None = None
+    rename: str = ""
+
+    def __post_init__(self):
+        if not self.rename:
+            self.rename = self.name
 
     def extract_value(self, mapping: dict) -> Any:
         """
@@ -39,7 +44,9 @@ class RecordSchema:
     """
     A schema for extracting a record of datafields
     """
+
     fields: list[FieldSchema]
+
     def extract_record(self, mapping: dict):
         """
         extracts record from dict
@@ -48,5 +55,13 @@ class RecordSchema:
         """
         record = {}
         for field in self.fields:
-            record[field.rename or field.name] = field.extract_value(mapping)
+            record[field.rename] = field.extract_value(mapping)
         return record
+
+    def get_field_names(self, renamed_names: bool = False):
+        """
+        returns field names, optionally the renamed ones
+        >>> RecordSchema([FieldSchema('x', int, rename='y')]).get_field_names(True)
+        ['y']
+        """
+        return [field.rename if renamed_names else field.name for field in self.fields]
